@@ -9,22 +9,28 @@ from rasterio import RasterioIOError
 from rasterio.io import MemoryFile
 
 
-def read_dem(url: str) -> rasterio.DatasetReader:
-    ds = rasterio.open(url)
+def read_dem(dem_path: str) -> rasterio.DatasetReader:
+    ds = rasterio.open(dem_path)
     return ds
 
 
-def read_glo(url: str) -> Union[rasterio.DatasetReader, None]:
+def read_glo(dem_path: str) -> Union[rasterio.DatasetReader, None]:
     # Some tiles do not exist
     try:
-        return read_dem(url)
+        return read_dem(dem_path)
     except RasterioIOError:
         return None
 
 
-def read_dem_bytes(url: str, suffix: str = '.img') -> bytes:
-    request = requests.get(url)
-    zip_ob = zipfile.ZipFile(io.BytesIO(request.content))
+def read_dem_bytes(dem_path: str, suffix: str = '.img') -> bytes:
+    # online
+    if (dem_path[:7] == 'http://') or (dem_path[:8] == 'https://'):
+        resp = requests.get(dem_path)
+        data = io.BytesIO(resp.content)
+    # local file
+    else:
+        data = dem_path
+    zip_ob = zipfile.ZipFile(data)
 
     filenames = zip_ob.filelist
 
@@ -36,8 +42,8 @@ def read_dem_bytes(url: str, suffix: str = '.img') -> bytes:
     return img_bytes
 
 
-def read_ned1(url: str) -> Tuple[np.ndarray, dict]:
-    img_bytes = read_dem_bytes(url, suffix='.img')
+def read_ned1(dem_path: str) -> Tuple[np.ndarray, dict]:
+    img_bytes = read_dem_bytes(dem_path, suffix='.img')
     with MemoryFile(img_bytes) as memfile:
         with memfile.open() as dataset:
             dem_arr = dataset.read(1)
@@ -46,10 +52,10 @@ def read_ned1(url: str) -> Tuple[np.ndarray, dict]:
     return dem_arr, dem_profile
 
 
-def read_srtm(url: str, version='srtm') -> Tuple[np.ndarray, dict]:
-    img_bytes = read_dem_bytes(url, suffix='.hgt')
+def read_srtm(dem_path: str, version='srtm') -> Tuple[np.ndarray, dict]:
+    img_bytes = read_dem_bytes(dem_path, suffix='.hgt')
     # The gdal driver hgt depends on filename convention
-    filename = url.split('/')[-1]
+    filename = dem_path.split('/')[-1]
     if version == 'srtm':
         filename = filename.replace('.zip', '')
     elif version == 'nasadem':
@@ -66,5 +72,5 @@ def read_srtm(url: str, version='srtm') -> Tuple[np.ndarray, dict]:
     return dem_arr, dem_profile
 
 
-def read_nasadem(url: str) -> Tuple[np.ndarray, dict]:
-    return read_srtm(url, version='nasadem')
+def read_nasadem(dem_path: str) -> Tuple[np.ndarray, dict]:
+    return read_srtm(dem_path, version='nasadem')
